/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2007-2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 */
package org.atmosphere.samples.pubsub;

import org.atmosphere.cpr.AtmosphereResource;
import org.atmosphere.cpr.AtmosphereResourceEvent;
import org.atmosphere.jersey.JerseyBroadcaster;
import org.atmosphere.util.LoggerUtils;

import java.util.concurrent.atomic.AtomicBoolean;

/**
 * A example of how to extends/replace {@link org.atmosphere.cpr.Broadcaster} by defining the
 * class value in META-INF/atmosphere.xml or by adding defining the org.atmosphere.cpr.broadcasterClass
 * init-param in web.xml.
 *
 * @author Jeanfrancois Arcand
 */
public class PubSubBroadcaster extends JerseyBroadcaster{

    private final AtomicBoolean isSet = new AtomicBoolean(false);

    public PubSubBroadcaster() {
        super();
    }

    public PubSubBroadcaster(String id) {
        super(id);
    }

    @Override
    protected void broadcast( final AtmosphereResource r, final AtmosphereResourceEvent e) {
        if (!isSet.getAndSet(true)) {
            LoggerUtils.getLogger().info("This is just an example that demonstrate " +
                    "how a Broadcaster can be customized using atmosphere.xml or by " +
                    "defining it inside web.xml");
        }
        
        super.broadcast(r,e);
    }
}
